package main

import (
	"context"
	"fmt"
	"time"

	"code.byted.org/caijing_pay/tp_golang_applet/tt_pay"
	"code.byted.org/caijing_pay/tp_golang_applet/tt_pay/config"
	"code.byted.org/caijing_pay/tp_golang_applet/tt_pay/util"
)

func main() {
	util.SetDebugMode(true)

	config := config.Config{
		AppId:             "__________________",             // 支付方分配给业务方的ID，用于获取 签名/验签 的密钥信息
		AppSecret:         "______________",                 // 支付方密钥
		MerchantId:        "_____________",                  // 支付方分配给业务方的商户编号
		TPDomain:          "https://tp-pay-test.snssdk.com", // 测试请用https://tp-pay-test.snssdk.com, 线上请用https://tp-pay.snssdk.com
		TPClientTimeoutMs: 6000,
	}
	req := tt_pay.NewRefundCreateRequest(config)
	req.Uid = "123"                                                   // 填写用户在头条的id
	req.OutOrderNo = "12345"                                          // 填写商户订单号
	req.OutRefundNo = "refund" + fmt.Sprintf("%d", time.Now().Unix()) // 此处是随机生成的，使用时请填写您的商户退款单号
	req.RefundAmount = 1                                              // 填写您的退款金额
	req.NotifyUrl = "https://google.com"                              // 填写您的异步通知地址
	req.RiskInfo = `{"ip":"127.0.0.1","device_id":"12313121"}`        // 严格json字符串格式

	ctx := context.Background()
	resp, err := tt_pay.RefundCreate(ctx, req)

	if err != nil {
		fmt.Printf("Request failed! \nRequest:\n  [%#v]\n", req)
		// 要方便获取网络错误的具体信息（code，msg，sub_code, sub_msg），需进行一次断言
		if nerr, ok := err.(*util.Error); ok {
			fmt.Printf("Error:\n  code:[%s] msg:[%s] sub_code:[%s] sub_msg:[%s]", nerr.Code, nerr.Msg, nerr.SubCode, nerr.SubMsg)
			return
		}
		fmt.Printf("Error:\n  [%s]", err)
		return
	}
	fmt.Printf("Request succeeded! \nRequest:\n [%#v]\nResponse:\n  [%#v]\n", req, resp)
}
